MCPcopy Create free account
hub / github.com/ROCm/rocPRIM / complete_value

Function complete_value

test/rocprim/test_device_scan.cpp:535–539  ·  view source on GitHub ↗

Source from the content-addressed store, hash-verified

533
534template<class T, class scan_state_type>
535__global__
536void complete_value(T* values, scan_state_type scan_state)
537{
538 values[blockIdx.x] = scan_state.get_complete_value(blockIdx.x);
539}
540
541TYPED_TEST(RocprimDeviceScanTests, LookBackScanGetCompleteValue)
542{

Callers

nothing calls this directly

Calls 1

get_complete_valueMethod · 0.45

Tested by

no test coverage detected